@@ -20,10 +20,16 @@
 # DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 # TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 # PERFORMANCE OF THIS SOFTWARE.
-TESTDIR=${srcdir-`pwd`}
+case "$OSTYPE" in
+    msys ) MyPWD=`pwd -W` ;;  # On Msys/MinGW, returns a MS Windows style path.
+    *    ) MyPWD=`pwd`    ;;  # On any other platforms, returns a Unix style path.
+esac
 
-FONTDIR=`pwd`/fonts
-CACHEDIR=`pwd`/cache.dir
+TESTDIR=${srcdir-"$MyPWD"}
+
+FONTDIR="$MyPWD"/fonts
+CACHEDIR="$MyPWD"/cache.dir
+EXPECTED=${EXPECTED-"out.expected"}
 
 ECHO=true
 
@@ -40,9 +46,9 @@ check () {
   echo "=" >> out
   $FCLIST - family pixelsize | sort >> out
   tr -d '\015' <out >out.tmp; mv out.tmp out
-  if cmp out $TESTDIR/out.expected > /dev/null ; then : ; else
+  if cmp out $TESTDIR/$EXPECTED > /dev/null ; then : ; else
     echo "*** Test failed: $TEST"
-    echo "*** output is in 'out', expected output in 'out.expected'"
+    echo "*** output is in 'out', expected output in '$EXPECTED'"
     exit 1
   fi
   rm out
@@ -62,7 +68,7 @@ dotest () {
 sed "s!@FONTDIR@!$FONTDIR!
 s!@CACHEDIR@!$CACHEDIR!" < $TESTDIR/fonts.conf.in > fonts.conf
 
-FONTCONFIG_FILE=`pwd`/fonts.conf
+FONTCONFIG_FILE="$MyPWD"/fonts.conf
 export FONTCONFIG_FILE
 
 dotest "Basic check"
